==> igniteui-react-charts-16.6.8.tgz: package/ES2015/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new PercentageVolumeOscillatorIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return PercentageVolumeOscillatorIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get shortPeriod() {
        return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qr));
    }
    set shortPeriod(a) {
        this.h(PercentageVolumeOscillatorIndicator.qr, a);
    }
    qd() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qq));
    }
    set longPeriod(a) {
        this.h(PercentageVolumeOscillatorIndicator.qq, a);
    }
    qa() {
        return this.longPeriod;
    }
}
PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
PercentageVolumeOscillatorIndicator.qr = StrategyBasedIndicator.qp(10, PercentageVolumeOscillatorIndicator.$);
PercentageVolumeOscillatorIndicator.qq = StrategyBasedIndicator.ql(30, PercentageVolumeOscillatorIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new PercentageVolumeOscillatorIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return PercentageVolumeOscillatorIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get shortPeriod() {
        return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qy));
    }
    set shortPeriod(a) {
        this.h(PercentageVolumeOscillatorIndicator.qy, a);
    }
    qk() {
        return this.shortPeriod;
    }
    get longPeriod() {
        return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.qx));
    }
    set longPeriod(a) {
        this.h(PercentageVolumeOscillatorIndicator.qx, a);
    }
    qh() {
        return this.longPeriod;
    }
}
PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
PercentageVolumeOscillatorIndicator.qy = StrategyBasedIndicator.qw(10, PercentageVolumeOscillatorIndicator.$);
PercentageVolumeOscillatorIndicator.qx = StrategyBasedIndicator.qs(30, PercentageVolumeOscillatorIndicator.$);
